@@ -1,4 +1,4 @@
-{-# LANGUAGE GADTs, Rank2Types, ScopedTypeVariables #-}
+{-# LANGUAGE GADTSyntax, ExistentialQuantification, Rank2Types, ScopedTypeVariables #-}
 {-# LANGUAGE UndecidableInstances, MultiParamTypeClasses, FlexibleInstances #-}
 -- Search for UndecidableInstances to see why this is needed
 
@@ -175,7 +175,7 @@ Stack machine from \"The Operational Monad Tutorial\".
 >        eval (Pop    :>>= is) (a:stack) = interpret (is a ) stack
 >        eval (Return a)       stack     = a
 
-Note that since 'ProgramView' is a GADT, the type annotation for @eval@ is mandatory.
+In this example, the type signature for the `eval` helper function is optional.
 
 -}
 
@@ -284,7 +284,7 @@ List monad transformer.
 >        eval (Plus m n :>>= k) =
 >            liftM2 (++) (runList (m >>= k)) (runList (n >>= k))
 
-Note that since 'ProgramView' is a GADT, the type annotation for @eval@ is mandatory.
+In this example, the type signature for the `eval` helper function is optional.
 
 -}
 
@@ -311,5 +311,5 @@ instance (MonadReader r m) => MonadReader r (ProgramT instr m) where
     
     local r (Lift m)     = Lift (local r m)
     local r (m `Bind` k) = local r m `Bind` (local r . k)
-    local r (Instr i)    = Instr i
+    local _ (Instr i)    = Instr i
 
